#!/bin/bash

## Copyright relates only to locking functionality

## Copyright (C) 2009  Przemyslaw Pawelczyk <przemoc@gmail.com>
## License: GNU General Public License v2, v3
#
# Lockable script boilerplate

### HEADER ###

LOCKFILE="/var/lock/`basename $0`"
LOCKFD=99

# PRIVATE
_lock()             { flock -$1 $LOCKFD; }
_no_more_locking()  { _lock u; _lock xn && rm -f $LOCKFILE; }
_prepare_locking()  { eval "exec $LOCKFD>\"$LOCKFILE\""; trap _no_more_locking EXIT; }

# ON START
_prepare_locking

# PUBLIC
exlock_now()        { _lock xn; }  # obtain an exclusive lock immediately or fail
exlock()            { _lock x; }   # obtain an exclusive lock
shlock()            { _lock s; }   # obtain a shared lock
unlock()            { _lock u; }   # drop a lock

### BEGIN OF SCRIPT ###

if [ -w /var/log ]; then
	exec 3>&1 4>&2
	trap 'exec 2>&4 1>&3' 0 1 2 3
	exec 1>/var/log/context.log 2>&1

	exlock
else
	# This happens on some systems, it depends how early udev first triggers
	echo "Not running without a writable filesystem"
	exit 1
fi

cwd=$(dirname `readlink -f $0 || realpath $0`)

ctxdir=$("$cwd"/copy.sh)
if [ $? -ne 0 ]; then
	echo "$ctxdir"
	exit 1
fi

"$cwd"/run.sh "$ctxdir"/context.sh "$ctxdir"/system.sh

unlock
